==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ImageCapturedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ImageCapturedEventArgsDescription } from "./ImageCapturedEventArgsDescription";
/**
 * @hidden
 */
export let ImageCapturedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ImageCapturedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ImageCapturedEventArgsDescriptionMetadata.a == null) {
                ImageCapturedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ImageCapturedEventArgsDescriptionMetadata.c(ImageCapturedEventArgsDescriptionMetadata.a);
            }
            if (a.k(ImageCapturedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(ImageCapturedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ImageCapturedEventArgsDescriptionMetadata.b(a);
            a.ad("ImageCapturedEventArgs", () => new ImageCapturedEventArgsDescription());
            a.ac("ImageCapturedEventArgs", ImageCapturedEventArgsDescriptionMetadata.a);
        }
    }
    ImageCapturedEventArgsDescriptionMetadata.$t = markType(ImageCapturedEventArgsDescriptionMetadata, 'ImageCapturedEventArgsDescriptionMetadata');
    ImageCapturedEventArgsDescriptionMetadata.a = null;
    return ImageCapturedEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ImageCapturedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ImageCapturedEventArgsDescription } from "./ImageCapturedEventArgsDescription";
/**
 * @hidden
 */
export let ImageCapturedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ImageCapturedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ImageCapturedEventArgsDescriptionMetadata.a == null) {
                ImageCapturedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ImageCapturedEventArgsDescriptionMetadata.c(ImageCapturedEventArgsDescriptionMetadata.a);
            }
            if (a.k(ImageCapturedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(ImageCapturedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ImageCapturedEventArgsDescriptionMetadata.b(a);
            a.ae("ImageCapturedEventArgs", () => new ImageCapturedEventArgsDescription());
            a.ad("ImageCapturedEventArgs", ImageCapturedEventArgsDescriptionMetadata.a);
        }
    }
    ImageCapturedEventArgsDescriptionMetadata.$t = markType(ImageCapturedEventArgsDescriptionMetadata, 'ImageCapturedEventArgsDescriptionMetadata');
    ImageCapturedEventArgsDescriptionMetadata.a = null;
    return ImageCapturedEventArgsDescriptionMetadata;
})();
